package com.mysql.jdbc.profiler;

import com.mysql.jdbc.Util;
import java.util.Date;

/* loaded from: com_mysql_jdbc_profiler.jar:com/mysql/jdbc/profiler/ProfilerEvent.class */
public class ProfilerEvent {
    public static final byte TYPE_WARN = 0;
    public static final byte TYPE_OBJECT_CREATION = 1;
    public static final byte TYPE_PREPARE = 2;
    public static final byte TYPE_QUERY = 3;
    public static final byte TYPE_EXECUTE = 4;
    public static final byte TYPE_FETCH = 5;
    public static final byte TYPE_SLOW_QUERY = 6;
    protected byte eventType;
    protected long connectionId;
    protected int statementId;
    protected int resultSetId;
    protected long eventCreationTime;
    protected long eventDuration;
    protected String durationUnits;
    protected int hostNameIndex;
    protected String hostName;
    protected int catalogIndex;
    protected String catalog;
    protected int eventCreationPointIndex;
    protected Throwable eventCreationPoint;
    protected String eventCreationPointDesc;
    protected String message;

    public ProfilerEvent(byte eventType, String hostName, String catalog, long connectionId, int statementId, int resultSetId, long eventCreationTime, long eventDuration, String durationUnits, String eventCreationPointDesc, Throwable eventCreationPoint, String message) {
        this.eventType = eventType;
        this.connectionId = connectionId;
        this.statementId = statementId;
        this.resultSetId = resultSetId;
        this.eventCreationTime = eventCreationTime;
        this.eventDuration = eventDuration;
        this.durationUnits = durationUnits;
        this.eventCreationPoint = eventCreationPoint;
        this.eventCreationPointDesc = eventCreationPointDesc;
        this.message = message;
    }

    public String getEventCreationPointAsString() {
        if (this.eventCreationPointDesc == null) {
            this.eventCreationPointDesc = Util.stackTraceToString(this.eventCreationPoint);
        }
        return this.eventCreationPointDesc;
    }

    public String toString() {
        StringBuffer buf = new StringBuffer(32);
        switch (this.eventType) {
            case TYPE_WARN /* 0 */:
                buf.append("WARN");
                break;
            case TYPE_OBJECT_CREATION /* 1 */:
                buf.append("CONSTRUCT");
                break;
            case TYPE_PREPARE /* 2 */:
                buf.append("PREPARE");
                break;
            case TYPE_QUERY /* 3 */:
                buf.append("QUERY");
                break;
            case TYPE_EXECUTE /* 4 */:
                buf.append("EXECUTE");
                break;
            case TYPE_FETCH /* 5 */:
                buf.append("FETCH");
                break;
            case TYPE_SLOW_QUERY /* 6 */:
                buf.append("SLOW QUERY");
                break;
            default:
                buf.append("UNKNOWN");
                break;
        }
        buf.append(" created: ");
        buf.append(new Date(this.eventCreationTime));
        buf.append(" duration: ");
        buf.append(this.eventDuration);
        buf.append(" connection: ");
        buf.append(this.connectionId);
        buf.append(" statement: ");
        buf.append(this.statementId);
        buf.append(" resultset: ");
        buf.append(this.resultSetId);
        if (this.message != null) {
            buf.append(" message: ");
            buf.append(this.message);
        }
        if (this.eventCreationPointDesc != null) {
            buf.append("\n\nEvent Created at:\n");
            buf.append(this.eventCreationPointDesc);
        }
        return buf.toString();
    }

    public static ProfilerEvent unpack(byte[] buf) throws Exception {
        int pos = 0 + 1;
        byte eventType = buf[0];
        long connectionId = readInt(buf, pos);
        int pos2 = pos + 8;
        int statementId = readInt(buf, pos2);
        int pos3 = pos2 + 4;
        int resultSetId = readInt(buf, pos3);
        int pos4 = pos3 + 4;
        long eventCreationTime = readLong(buf, pos4);
        int pos5 = pos4 + 8;
        long eventDuration = readLong(buf, pos5);
        int pos6 = pos5 + 4;
        byte[] eventDurationUnits = readBytes(buf, pos6);
        int pos7 = pos6 + 4;
        if (eventDurationUnits != null) {
            pos7 += eventDurationUnits.length;
        }
        readInt(buf, pos7);
        int pos8 = pos7 + 4;
        byte[] eventCreationAsBytes = readBytes(buf, pos8);
        int pos9 = pos8 + 4;
        if (eventCreationAsBytes != null) {
            pos9 += eventCreationAsBytes.length;
        }
        byte[] message = readBytes(buf, pos9);
        int pos10 = pos9 + 4;
        if (message != null) {
            int length = pos10 + message.length;
        }
        return new ProfilerEvent(eventType, "", "", connectionId, statementId, resultSetId, eventCreationTime, eventDuration, new String(eventDurationUnits, "ISO8859_1"), new String(eventCreationAsBytes, "ISO8859_1"), null, new String(message, "ISO8859_1"));
    }

    public byte[] pack() throws Exception {
        int len;
        int len2;
        int len3;
        int pos;
        byte[] eventCreationAsBytes = null;
        getEventCreationPointAsString();
        if (this.eventCreationPointDesc != null) {
            eventCreationAsBytes = this.eventCreationPointDesc.getBytes("ISO8859_1");
            len = 29 + 4 + eventCreationAsBytes.length;
        } else {
            len = 29 + 4;
        }
        byte[] messageAsBytes = null;
        if (0 != 0) {
            messageAsBytes = this.message.getBytes("ISO8859_1");
            len2 = len + 4 + messageAsBytes.length;
        } else {
            len2 = len + 4;
        }
        byte[] durationUnitsAsBytes = null;
        if (this.durationUnits != null) {
            durationUnitsAsBytes = this.durationUnits.getBytes("ISO8859_1");
            len3 = len2 + 4 + durationUnitsAsBytes.length;
        } else {
            len3 = len2 + 4;
        }
        byte[] buf = new byte[len3];
        buf[0] = this.eventType;
        int pos2 = writeInt(this.eventCreationPointIndex, buf, writeBytes(durationUnitsAsBytes, buf, writeLong(this.eventDuration, buf, writeLong(this.eventCreationTime, buf, writeInt(this.resultSetId, buf, writeInt(this.statementId, buf, writeLong(this.connectionId, buf, 0 + 1)))))));
        if (eventCreationAsBytes != null) {
            pos = writeBytes(eventCreationAsBytes, buf, pos2);
        } else {
            pos = writeInt(0, buf, pos2);
        }
        if (messageAsBytes != null) {
            writeBytes(messageAsBytes, buf, pos);
        } else {
            writeInt(0, buf, pos);
        }
        return buf;
    }

    private static int writeInt(int i, byte[] buf, int pos) {
        int pos2 = pos + 1;
        buf[pos] = (byte) (i & 255);
        int pos3 = pos2 + 1;
        buf[pos2] = (byte) (i >>> 8);
        int pos4 = pos3 + 1;
        buf[pos3] = (byte) (i >>> 16);
        int pos5 = pos4 + 1;
        buf[pos4] = (byte) (i >>> 24);
        return pos5;
    }

    private static int writeLong(long l, byte[] buf, int pos) {
        int pos2 = pos + 1;
        buf[pos] = (byte) (l & 255);
        int pos3 = pos2 + 1;
        buf[pos2] = (byte) (l >>> 8);
        int pos4 = pos3 + 1;
        buf[pos3] = (byte) (l >>> 16);
        int pos5 = pos4 + 1;
        buf[pos4] = (byte) (l >>> 24);
        int pos6 = pos5 + 1;
        buf[pos5] = (byte) (l >>> 32);
        int pos7 = pos6 + 1;
        buf[pos6] = (byte) (l >>> 40);
        int pos8 = pos7 + 1;
        buf[pos7] = (byte) (l >>> 48);
        int pos9 = pos8 + 1;
        buf[pos8] = (byte) (l >>> 56);
        return pos9;
    }

    private static int writeBytes(byte[] msg, byte[] buf, int pos) {
        int pos2 = writeInt(msg.length, buf, pos);
        System.arraycopy(msg, 0, buf, pos2, msg.length);
        return pos2 + msg.length;
    }

    private static int readInt(byte[] buf, int pos) {
        int pos2 = pos + 1;
        int i = buf[pos] & 255;
        int pos3 = pos2 + 1;
        int i2 = i | ((buf[pos2] & 255) << 8);
        int pos4 = pos3 + 1;
        int i3 = i2 | ((buf[pos3] & 255) << 16);
        int i4 = pos4 + 1;
        return i3 | ((buf[pos4] & 255) << 24);
    }

    private static long readLong(byte[] buf, int pos) {
        long j = buf[pos] & 255;
        long j2 = j | ((buf[r7] & 255) << 8);
        long j3 = j2 | ((buf[r7] & 255) << 16);
        long j4 = j3 | ((buf[r7] & 255) << 24);
        long j5 = j4 | ((buf[r7] & 255) << 32);
        long j6 = j5 | ((buf[r7] & 255) << 40);
        long j7 = j6 | ((buf[r7] & 255) << 48);
        int i = pos + 1 + 1 + 1 + 1 + 1 + 1 + 1 + 1;
        return j7 | ((buf[r7] & 255) << 56);
    }

    private static byte[] readBytes(byte[] buf, int pos) {
        int length = readInt(buf, pos);
        byte[] msg = new byte[length];
        System.arraycopy(buf, pos + 4, msg, 0, length);
        return msg;
    }

    public String getCatalog() {
        return this.catalog;
    }

    public long getConnectionId() {
        return this.connectionId;
    }

    public Throwable getEventCreationPoint() {
        return this.eventCreationPoint;
    }

    public long getEventCreationTime() {
        return this.eventCreationTime;
    }

    public long getEventDuration() {
        return this.eventDuration;
    }

    public String getDurationUnits() {
        return this.durationUnits;
    }

    public byte getEventType() {
        return this.eventType;
    }

    public int getResultSetId() {
        return this.resultSetId;
    }

    public int getStatementId() {
        return this.statementId;
    }

    public String getMessage() {
        return this.message;
    }
}
